// Copyright (c) Microsoft Corporation.
// Licensed under the MIT license.
/**
 * @internal
 */
export const multiTenantErrorMessage = "A getToken request was attempted with a tenant different than the tenant configured at the initialization of the credential, but multi-tenant authentication was not enabled in this credential instance.";
/**
 * Verifies whether locally assigned tenants are equal to tenants received through getToken.
 * Returns the appropriate tenant.
 * @internal
 */
export function processMultiTenantRequest(tenantId, allowMultiTenantAuthentication, getTokenOptions) {
    if (!allowMultiTenantAuthentication &&
        (getTokenOptions === null || getTokenOptions === void 0 ? void 0 : getTokenOptions.tenantId) &&
        tenantId &&
        getTokenOptions.tenantId !== tenantId) {
        throw new Error(multiTenantErrorMessage);
    }
    if (allowMultiTenantAuthentication && (getTokenOptions === null || getTokenOptions === void 0 ? void 0 : getTokenOptions.tenantId)) {
        return getTokenOptions.tenantId;
    }
    return tenantId;
}
//# sourceMappingURL=validateMultiTenant.js.map